@@ -6,6 +6,8 @@ __all__ = [
     'HookimplMarker',
     'contextmanager',
     'asynccontextmanager',
+    'async_stack_gen_ctxs',
+    'stack_gen_ctxs',
 ]
 
 
@@ -13,4 +15,5 @@ from decorator import contextmanager
 from pluggy import HookCallError, HookimplMarker, HookspecMarker, PluginValidationError
 
 from ._decorator import asynccontextmanager
-from ._wrap import PluginManager
+from .stack import async_stack_gen_ctxs, stack_gen_ctxs
+from .wrap import PluginManager
